@@ -47,8 +47,11 @@ class Dupamb:
         f.close()
 import sys
 def main():
-    filename = sys.argv[1]
-    obj = Dupamb(filename)
-    obj.removeDupAmb()
+	try:
+		filename = sys.argv[1]
+    	obj = Dupamb(filename)
+    	obj.removeDupAmb()
+    except:
+    	print("Exception occurred")
 if __name__=="__main__":
     main()
\ No newline at end of file
